@@ -10,8 +10,9 @@
 #' @description `reprex_selection()` is an
 #'   [addin](http://rstudio.github.io/rstudioaddins/) that reprexes the current
 #'   selection, optionally customised by options. Appears as "Reprex selection"
-#'   in the RStudio Addins menu. Heavy users might want to [create a keyboard
-#'   shortcut](https://support.rstudio.com/hc/en-us/articles/206382178-Customizing-Keyboard-Shortcuts).
+#'   in the RStudio Addins menu. Heavy users might want to create a keyboard
+#'   shortcut, which is described in
+#'   `https://support.rstudio.com/hc/en-us/articles/206382178-Customizing-Keyboard-Shortcuts`.
 #'   Suggested shortcut: Cmd + Shift + R (macOS) or Ctrl + Shift + R (Windows).
 #'
 #' @export
@@ -96,8 +97,7 @@ reprex_addin <- function() { # nocov start
 
 reprex_guess <- function(source, venue = "gh", source_file = NULL,
                          session_info = FALSE, html_preview = FALSE) {
-  reprex_input <- switch(
-    source,
+  reprex_input <- switch(source,
     clipboard = NULL,
     cur_sel = rstudio_selection(),
     cur_file = rstudio_file(),
@@ -136,7 +136,7 @@ rstudio_context <- function() {
 # nocov end
 
 rstudio_text_tidy <- function(x) {
-  if (x == "") {
+  if (identical(x, "")) {
     return(character())
   }
   Encoding(x) <- "UTF-8"
@@ -151,4 +151,3 @@ rstudio_text_tidy <- function(x) {
   }
   x
 }
-
